==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/ProvidedSignalBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBody;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedSignalSetImpl;

import java.util.Arrays;
import java.util.List;


public class ProvidedSignalBodySetImpl extends InstanceSet<ProvidedSignalBodySet,ProvidedSignalBody> implements ProvidedSignalBodySet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ProvidedSignalBody providedsignalbody : this ) providedsignalbody.setId( ref_Id );
    }
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( ProvidedSignalBody providedsignalbody : this ) providedsignalbody.setAction_ID( ref_Action_ID );
    }


    // selections
    @Override
    public ProvidedSignalSet R686_specifies_processing_for_ProvidedSignal() throws XtumlException {
        ProvidedSignalSet providedsignalset = new ProvidedSignalSetImpl();
        for ( ProvidedSignalBody providedsignalbody : this ) providedsignalset.add( providedsignalbody.R686_specifies_processing_for_ProvidedSignal() );
        return providedsignalset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( ProvidedSignalBody providedsignalbody : this ) bodyset.add( providedsignalbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public ProvidedSignalBody nullElement() {
        return ProvidedSignalBodyImpl.EMPTY_PROVIDEDSIGNALBODY;
    }

    @Override
    public ProvidedSignalBodySet emptySet() {
      return new ProvidedSignalBodySetImpl();
    }

    @Override
    public ProvidedSignalBodySet value() {
        return this;
    }

    @Override
    public List<ProvidedSignalBody> elements() {
        return Arrays.asList(toArray(new ProvidedSignalBody[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/ProvidedSignalBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBody;
import io.ciera.tool.sql.ooaofooa.body.ProvidedSignalBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedSignalSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.impl.ProvidedSignalSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ProvidedSignalBodySetImpl extends InstanceSet<ProvidedSignalBodySet,ProvidedSignalBody> implements ProvidedSignalBodySet {

    public ProvidedSignalBodySetImpl() {
    }

    public ProvidedSignalBodySetImpl(Comparator<? super ProvidedSignalBody> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ProvidedSignalBody providedsignalbody : this ) providedsignalbody.setId( ref_Id );
    }
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( ProvidedSignalBody providedsignalbody : this ) providedsignalbody.setAction_ID( ref_Action_ID );
    }


    // selections
    @Override
    public ProvidedSignalSet R686_specifies_processing_for_ProvidedSignal() throws XtumlException {
        ProvidedSignalSet providedsignalset = new ProvidedSignalSetImpl();
        for ( ProvidedSignalBody providedsignalbody : this ) providedsignalset.add( providedsignalbody.R686_specifies_processing_for_ProvidedSignal() );
        return providedsignalset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( ProvidedSignalBody providedsignalbody : this ) bodyset.add( providedsignalbody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public ProvidedSignalBody nullElement() {
        return ProvidedSignalBodyImpl.EMPTY_PROVIDEDSIGNALBODY;
    }

    @Override
    public ProvidedSignalBodySet emptySet() {
      return new ProvidedSignalBodySetImpl();
    }

    @Override
    public ProvidedSignalBodySet emptySet(Comparator<? super ProvidedSignalBody> comp) {
      return new ProvidedSignalBodySetImpl(comp);
    }

    @Override
    public ProvidedSignalBodySet value() {
        return this;
    }

    @Override
    public List<ProvidedSignalBody> elements() {
        return Arrays.asList(toArray(new ProvidedSignalBody[0]));
    }

}
